@@ -30,6 +30,7 @@
 #include <QVBoxLayout>
 #include <QLatin1String>
 #include <QList>
+#include <QTime>
 #include <QStackedWidget>
 #include <QSizePolicy>
 
@@ -42,6 +43,7 @@
 #include "nowplaying.h"
 #include "playlistbox.h"
 #include "lyricswidget.h"
+#include "mpris2/mpris2.h"
 
 ////////////////////////////////////////////////////////////////////////////////
 // public methods
@@ -322,8 +324,13 @@ void PlaylistSplitter::slotPlaylistChanged(int i)
 
 void PlaylistSplitter::slotEnable()
 {
+    kDebug() << "Enabling GUI";
+    QTime stopwatch; stopwatch.start();
     setEnabled(true); // Ready to go.
     m_playlistStack->show();
+    kDebug() << "Finished enabling GUI, took" << stopwatch.elapsed() << "ms";
+
+    (void) new Mpris2(this);
 }
 
 #include "playlistsplitter.moc"
